@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 
 """ @if gnuheader
 #############################################################################
@@ -46,7 +46,7 @@ from __future__ import division
 from __future__ import print_function
 
 # pytango imports
-from builtins import str
+#from builtins import str
 from past.utils import old_div
 import PyTango
 import types
