@@ -2,7 +2,7 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import with_statement
-from builtins import str
+#from builtins import str
 from past.utils import old_div
 from builtins import object
 
