@@ -44,7 +44,7 @@ from builtins import chr
 from builtins import filter
 from builtins import next
 from builtins import zip
-from builtins import str
+#from builtins import str #NOPE! breaks joins
 from builtins import map
 from builtins import range
 from past.builtins import basestring, unicode
@@ -859,7 +859,7 @@ def isSequence(seq, iterators=True, **kwargs):
     return False
 
 
-def isDictionary(seq, strict=False):
+def isDictionary(seq, strict=True):
     """
     It includes dict-like and also nested lists if strict is False
     """
@@ -872,7 +872,7 @@ def isDictionary(seq, strict=False):
     try:
         if seq and isSequence(seq) and isSequence(seq[0]):
             # First element of tuple must be key-like
-            if seq[0] and not isIterable(seq[0][0]):
+            if seq[0] and len(seq[0])==2: #seq[0] and not isIterable(seq[0][0]):
                 return True
     except:
         pass
