@@ -52,7 +52,7 @@ from __future__ import print_function
 from future import standard_library
 
 standard_library.install_aliases()
-from builtins import str
+#from builtins import str
 from builtins import zip
 from builtins import map
 from builtins import range
@@ -81,6 +81,7 @@ def shell_command(*commands, **keywords):
     elif isinstance(commands, str):
         commands = [commands]
     split = keywords and "split" in keywords and keywords["split"]
+    decode = keywords.get("decode","utf-8" if fun.py3 else False)
     import subprocess
 
     process = [subprocess.Popen(commands[0], shell=True, stdout=subprocess.PIPE)]
@@ -95,9 +96,7 @@ def shell_command(*commands, **keywords):
         result and len(result) >= 1 and result[0]
     ) or None  # process returns a tuple, being stdout the first field
 
-    # python2/3 compatibility
     try:
-        decode = keywords.get("decode","utf-8")
         result = bytes.decode(result,decode) if decode else result
     except:
         pass
@@ -106,7 +105,7 @@ def shell_command(*commands, **keywords):
     if not result:
         return
     elif split:
-        return result.split("\n")
+        return list(result.split("\n"))
     else:
         return result
 
