@@ -7,7 +7,6 @@ standard_library.install_aliases()
 from builtins import filter
 #from builtins import str
 from builtins import range
-from future.utils import raise_
 from past.utils import old_div
 import time, traceback, os, sys, threading, datetime
 import collections, re
@@ -210,7 +209,7 @@ class TServer(Object):
 
     def __init__(self, name="", host="", parent=None):
         if not name or "/" not in name:
-            raise_(Exception, "TServer_WrongServerName_%s" % name)
+            raise Exception("TServer_WrongServerName_%s" % name)
         self.name = self.get_simple_name(name)
         self.update_level(host, 0)
         self.controlled = False
@@ -285,7 +284,7 @@ class TServer(Object):
             return self._classes
         devs = self._db.get_device_class_list(self.name)
         self._classes = collections.defaultdict(list)
-        # print 'loading from %s server:%s'%(s,str(devs))
+        # print('loading from %s server:%s'%(s,str(devs)))
         for i in range(0, len(devs), 2):
             klass = devs[i + 1]
             self._classes[klass].append(devs[i].lower())
@@ -557,7 +556,7 @@ class ServersDict(CaselessDict, Object):
             except Exception as e:
                 print("exception loading %s server: %s" % (s, str(e)[:100] + "..."))
                 print(traceback.format_exc())
-        # print 'load_from_servers_list(%d) took %f seconds' % (len(servers_list),time.time()-t0)
+        # print('load_from_servers_list(%d) took %f seconds' % (len(servers_list),time.time()-t0))
 
     def check_servers_names(self, servers_list):
         """Crosschecks the name of servers (case sensitive) with names retrieved by self.db.get_server_list()"""
@@ -777,7 +776,7 @@ class ServersDict(CaselessDict, Object):
                 raise ImportError
             from threads import AsynchronousFunction
 
-            # print 'UPDATE_STATES USING ASYNCHRONOUS CALLS'
+            # print('UPDATE_STATES USING ASYNCHRONOUS CALLS')
             def try_device(sdict, server):
                 try:
                     # self.log.debug('try_device(%s)'% (server))
