@@ -45,11 +45,13 @@ Methods for Astor-like management will go to fandango.servers
 from __future__ import division
 from __future__ import print_function
 
-from builtins import str
+#from builtins import str
 from past.utils import old_div
 from builtins import object
-from .methods import *
-from .search import *
+
+import fandango as fn
+from fandango.tango.methods import *
+from fandango.tango.search import *
 
 ##############################################################################################################
 ## Tango formula evaluation
@@ -276,15 +278,15 @@ class TangoEval(object):
             else:
                 proxy = lambda a: CachedAttributeProxy(a, keeptime=self.keeptime)
 
-            self.attributes = dicts.CaselessDefaultDict(proxy)
+            self.attributes = fn.CaselessDefaultDict(proxy)
 
         # Keeps last values for each variable
-        self.previous = dicts.CaselessDict()
+        self.previous = fn.CaselessDict()
         # Keeps values from the last eval execution only
-        self.last = dicts.CaselessDict()
+        self.last = fn.CaselessDict()
         self.cache_depth = cache
         self.cache = (
-            dicts.CaselessDefaultDict(lambda k: list()) if self.cache_depth else None
+            fn.CaselessDefaultDict(lambda k: list()) if self.cache_depth else None
         )  # Keeps [cache]
         self.result = None
         self.macros = [("FIND(%s)", self.FIND_EXP, self.find_macro)]
