@@ -1,6 +1,6 @@
 from __future__ import print_function
 from builtins import map
-from builtins import str
+#from builtins import str
 import fandango as fn, fandango.callbacks as fc
 
 attrs = list(map(str.lower, fn.get_matching_attributes("bl00*eps*plc*01/*")))
